This is the main driver for flexmixNL interfacing the
family of Generalized Nonlinear Models.
FLXMRnlm(formula = . ~ .,
family = c("gaussian", "Gamma"),
start = list(),
offset = NULL)A model formula decribing the nonlinear predictor
and including variables and regression parameters.
A character string naming a family function
(family="gaussian" or family="Gamma" available).
A list of starting values for the regression parameters.
Specification of an a priori known component to be included in the nonlinear predictor during fitting.
Returns an object of class FLXMRnlm.
Models for FLXMRnlm are specified by a model formula
(formula argument) relating the response to a
nonlinear predictor.
When fitting normal mixture models (family="gaussian") the nonlinear
predictor is explicitely formulated (see also nls).
When fitting gamma mixture models (family="Gamma") the nonlinear
predictor is specified by a symbolic description (see also gnm).
Variables not included in the data frame (see also flexmix)
are identified as the regression parameters. Starting values are required for
every regression parameter.
See flexmixNL for examples.